@@ -1,6 +1,8 @@
 {% import "macros.kt" as kt %}
 {%- let rec = self.inner() %}
-data class {{ rec|type_name }} (
+{%- let type_name = rec|type_name %}
+
+data class {{ type_name }} (
     {%- for field in rec.fields() %}
     var {{ field.name()|var_name }}: {{ field|type_name -}}
     {%- match field.default_value() %}
@@ -10,30 +12,6 @@ data class {{ rec|type_name }} (
     {% if !loop.last %}, {% endif %}
     {%- endfor %}
 ) {% if self.contains_object_references() %}: Disposable {% endif %}{
-    companion object {
-        internal fun lift(rbuf: RustBuffer.ByValue): {{ rec|type_name }} {
-            return liftFromRustBuffer(rbuf) { buf -> {{ rec|type_name }}.read(buf) }
-        }
-
-        internal fun read(buf: ByteBuffer): {{ rec|type_name }} {
-            return {{ rec|type_name }}(
-            {%- for field in rec.fields() %}
-            {{ "buf"|read_var(field) }}{% if loop.last %}{% else %},{% endif %}
-            {%- endfor %}
-            )
-        }
-    }
-
-    internal fun lower(): RustBuffer.ByValue {
-        return lowerIntoRustBuffer(this, {v, buf -> v.write(buf)})
-    }
-
-    internal fun write(buf: RustBufferBuilder) {
-        {%- for field in rec.fields() %}
-            {{ "this.{}"|format(field.name())|write_var("buf", field) }}
-        {% endfor %}
-    }
-
     {% if self.contains_object_references() %}
     @Suppress("UNNECESSARY_SAFE_CALL") // codegen is much simpler if we unconditionally emit safe calls here
     override fun destroy() {
@@ -41,3 +19,27 @@ data class {{ rec|type_name }} (
     }
     {% endif %}
 }
+
+internal object {{ rec|ffi_converter_name }} {
+    fun lift(rbuf: RustBuffer.ByValue): {{ type_name }} {
+        return liftFromRustBuffer(rbuf) { buf -> read(buf) }
+    }
+
+    fun read(buf: ByteBuffer): {{ type_name }} {
+        return {{ type_name }}(
+        {%- for field in rec.fields() %}
+            {{ field|read_fn }}(buf),
+        {%- endfor %}
+        )
+    }
+
+    fun lower(value: {{ type_name }}): RustBuffer.ByValue {
+        return lowerIntoRustBuffer(value, {v, buf -> write(v, buf)})
+    }
+
+    fun write(value: {{ type_name }}, buf: RustBufferBuilder) {
+        {%- for field in rec.fields() %}
+            {{ field|write_fn }}(value.{{ field.name()|var_name }}, buf)
+        {% endfor %}
+    }
+}
