@@ -9,8 +9,7 @@
 {%- when Some with (return_type) %}
 
 fun {{ func.name()|fn_name }}({%- call kt::arg_list_decl(func) -%}): {{ return_type|type_name }} {
-    val _retval = {% call kt::to_ffi_call(func) %}
-    return {{ "_retval"|lift_var(return_type) }}
+    return {{ return_type|lift_fn }}({% call kt::to_ffi_call(func) %})
 }
 
 {% when None -%}
