@@ -1,7 +1,7 @@
 {#
 // Template to call into rust. Used in several places.
 // Variable names in `arg_list_decl` should match up with arg lists
-// passed to rust via `_arg_list_ffi_call` (we use  `var_name` in `lower_var`)
+// passed to rust via `_arg_list_ffi_call`
 #}
 
 {%- macro to_ffi_call(func) -%}
@@ -10,8 +10,8 @@
     rustCallWithError({{ e|exception_name}})
     {%- else %}
     rustCall()
-    {%- endmatch %} { status ->
-    _UniFFILib.INSTANCE.{{ func.ffi_func().name() }}({% call _arg_list_ffi_call(func) -%}{% if func.arguments().len() > 0 %},{% endif %}status)
+    {%- endmatch %} { _status ->
+    _UniFFILib.INSTANCE.{{ func.ffi_func().name() }}({% call _arg_list_ffi_call(func) -%}{% if func.arguments().len() > 0 %},{% endif %} _status)
 }
 {%- endmacro -%}
 
@@ -21,15 +21,15 @@
     rustCallWithError({{ e|exception_name}})
     {%- else %}
     rustCall()
-    {%- endmatch %} { status ->
+    {%- endmatch %} { _status ->
     _UniFFILib.INSTANCE.{{ func.ffi_func().name() }}(
-        {{- prefix }}, {% call _arg_list_ffi_call(func) %}{% if func.arguments().len() > 0 %}, {% endif %}status)
+        {{- prefix }}, {% call _arg_list_ffi_call(func) %}{% if func.arguments().len() > 0 %}, {% endif %} _status)
 }
 {%- endmacro %}
 
 {%- macro _arg_list_ffi_call(func) %}
     {%- for arg in func.arguments() %}
-        {{- arg.name()|lower_var(arg) }}
+        {{- arg|lower_fn }}({{ arg.name()|var_name }})
         {%- if !loop.last %}, {% endif %}
     {%- endfor %}
 {%- endmacro -%}
@@ -64,7 +64,7 @@
     {%- for arg in func.arguments() %}
         {{- arg.name() }}: {{ arg.type_()|ffi_type_name -}},
     {%- endfor %}
-    uniffi_out_err: RustCallStatus
+    _uniffi_out_err: RustCallStatus
 {%- endmacro -%}
 
 // Macro for destroying fields
