@@ -4,10 +4,10 @@
 class FfiConverter{{ name }}(FfiConverterUsingByteBuffer):
     @staticmethod
     def _write(value, buf):
-        from {{ crate_name|fn_name_py }} import {{ name }};
+        from {{ crate_name|fn_name }} import {{ name }};
         {{ name }}._write(value, buf)
 
     @staticmethod
     def _read(buf):
-        from {{ crate_name|fn_name_py }} import {{ name }};
+        from {{ crate_name|fn_name }} import {{ name }};
         return {{ name }}._read(buf)
