@@ -8,8 +8,24 @@
 
 {%- macro _arg_list_rs_call(func) %}
     {%- for arg in func.full_arguments() %}
-        {%- if arg.by_ref() %}&{% endif %}
-        {{- arg.type_()|ffi_converter }}::try_lift({{ arg.name() }}).unwrap()
+        match {{- arg.type_()|ffi_converter }}::try_lift({{ arg.name() }}) {
+        {%- if arg.by_ref() %}
+            Ok(ref val) => val,
+        {% else %}
+            Ok(val) => val,
+        {% endif %}
+
+        {# If this function returns an error, we attempt to downcast errors doing arg
+            conversions to this error. If the downcast fails or the function doesn't
+            return an error, we just panic.
+        #}
+        {%- match func.throws_type() -%}
+        {%- when Some with (e) %}
+            Err(err) => return Err(uniffi::lower_anyhow_error_or_panic::<{{ e|ffi_converter_name }}>(err, "{{ arg.name() }}")),
+        {%- else %}
+            Err(err) => panic!("Failed to convert arg '{}': {}", "{{ arg.name() }}", err),
+        {%- endmatch %}
+        }
         {%- if !loop.last %}, {% endif %}
     {%- endfor %}
 {%- endmacro -%}
